RadioProps<T> class
单选字段配置
Constructors
-
RadioProps({required List<
SelectData< options, void onChanged(dynamic, T, SelectData<T> >T> )?}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onChanged
→ void Function(dynamic, T, SelectData<
T> )? -
final
-
options
→ List<
SelectData< T> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited