TextFieldProps class

文本字段配置属性

Constructors

TextFieldProps({int? minLength, int? maxLength, TextInputType? keyboardType, List<TextInputFormatter>? inputFormatters, void onChanged(String val)?})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
inputFormatters → List<TextInputFormatter>?
final
keyboardType → TextInputType?
final
maxLength → int?
final
minLength → int?
final
onChanged → void Function(String val)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited