UploadResult class

Constructors

UploadResult({required UploadSource source, required String name, String? path, Uint8List? bytes, int? size, String? mimeType})
const

Properties

bytes Uint8List?
final
hashCode int
The hash code for this object.
no setterinherited
mimeType String?
final
name String
final
path String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
final
source UploadSource
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited